@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -14,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5Gcompact.c
- *			Sep  5 2005
- *			Quincey Koziol
  *
  * Purpose:		Functions for handling compact storage.
  *
@@ -40,7 +37,7 @@ typedef struct {
 /* User data for deleting a link in the link messages */
 typedef struct {
     /* downward */
-    H5F_t *     file;            /* File that object header is located within */
+    H5F_t      *file;            /* File that object header is located within */
     H5RS_str_t *grp_full_path_r; /* Full path for group of link */
     const char *name;            /* Link name to search for */
 } H5G_iter_rm_t;
@@ -52,7 +49,7 @@ typedef struct {
 
     /* upward */
     H5O_link_t *lnk;   /* Link struct to fill in */
-    hbool_t     found; /* Flag to indicate that the object was found */
+    bool       *found; /* Pointer to flag to indicate that the object was found */
 } H5G_iter_lkp_t;
 
 /* Private macros */
@@ -71,28 +68,25 @@ static herr_t H5G__compact_lookup_cb(const void *_mesg, unsigned H5_ATTR_UNUSED
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep  5 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5G__compact_build_table_cb(const void *_mesg, unsigned H5_ATTR_UNUSED idx, void *_udata)
 {
     const H5O_link_t *lnk       = (const H5O_link_t *)_mesg; /* Pointer to link */
-    H5G_iter_bt_t *   udata     = (H5G_iter_bt_t *)_udata;   /* 'User data' passed in */
+    H5G_iter_bt_t    *udata     = (H5G_iter_bt_t *)_udata;   /* 'User data' passed in */
     herr_t            ret_value = H5_ITER_CONT;              /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk);
-    HDassert(udata);
-    HDassert(udata->curr_lnk < udata->ltable->nlinks);
+    assert(lnk);
+    assert(udata);
+    assert(udata->curr_lnk < udata->ltable->nlinks);
 
     /* Copy link message into table */
     if (NULL == H5O_msg_copy(H5O_LINK_ID, lnk, &(udata->ltable->lnks[udata->curr_lnk])))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message");
 
     /* Increment current link entry to operate on */
     udata->curr_lnk++;
@@ -110,9 +104,6 @@ done:
  * Return:	Success:        Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *	        Sep  6, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -121,12 +112,12 @@ H5G__compact_build_table(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_ind
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(oloc);
-    HDassert(linfo);
-    HDassert(ltable);
+    assert(oloc);
+    assert(linfo);
+    assert(ltable);
 
     /* Set size of table */
     H5_CHECK_OVERFLOW(linfo->nlinks, hsize_t, size_t);
@@ -138,8 +129,8 @@ H5G__compact_build_table(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_ind
         H5O_mesg_operator_t op;    /* Message operator */
 
         /* Allocate the link table */
-        if ((ltable->lnks = (H5O_link_t *)H5MM_malloc(sizeof(H5O_link_t) * ltable->nlinks)) == NULL)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+        if ((ltable->lnks = (H5O_link_t *)H5MM_calloc(sizeof(H5O_link_t) * ltable->nlinks)) == NULL)
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
         /* Set up user data for iteration */
         udata.ltable   = ltable;
@@ -149,11 +140,11 @@ H5G__compact_build_table(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_ind
         op.op_type  = H5O_MESG_OP_APP;
         op.u.app_op = H5G__compact_build_table_cb;
         if (H5O_msg_iterate(oloc, H5O_LINK_ID, &op, &udata) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages")
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages");
 
         /* Sort link table in correct iteration order */
         if (H5G__link_sort_table(ltable, idx_type, order) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTSORT, FAIL, "error sorting link messages")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTSORT, FAIL, "error sorting link messages");
     } /* end if */
     else
         ltable->lnks = NULL;
@@ -171,9 +162,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  6 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -184,12 +172,12 @@ H5G__compact_insert(const H5O_loc_t *grp_oloc, H5O_link_t *obj_lnk)
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(grp_oloc && grp_oloc->file);
-    HDassert(obj_lnk);
+    assert(grp_oloc && grp_oloc->file);
+    assert(obj_lnk);
 
     /* Insert link message into group */
     if (H5O_msg_create(grp_oloc, H5O_LINK_ID, 0, H5O_UPDATE_TIME, obj_lnk) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -200,48 +188,45 @@ done:
  *
  * Purpose:     Returns the name of objects in the group by giving index.
  *
- * Return:	Success:        Non-negative, length of name
- *		Failure:	Negative
- *
- * Programmer:	Quincey Koziol
- *	        Sep  6, 2005
+ * Return:	Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
-ssize_t
+herr_t
 H5G__compact_get_name_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_index_t idx_type,
-                             H5_iter_order_t order, hsize_t idx, char *name, size_t size)
+                             H5_iter_order_t order, hsize_t idx, char *name, size_t name_size,
+                             size_t *name_len)
 {
     H5G_link_table_t ltable    = {0, NULL}; /* Link table */
-    ssize_t          ret_value = -1;        /* Return value */
+    herr_t           ret_value = SUCCEED;   /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(oloc);
+    assert(oloc);
 
     /* Build table of all link messages */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Check for going out of bounds */
     if (idx >= ltable.nlinks)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "index out of bound")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "index out of bound");
 
     /* Get the length of the name */
-    ret_value = (ssize_t)HDstrlen(ltable.lnks[idx].name);
+    *name_len = strlen(ltable.lnks[idx].name);
 
     /* Copy the name into the user's buffer, if given */
     if (name) {
-        HDstrncpy(name, ltable.lnks[idx].name, MIN((size_t)(ret_value + 1), size));
-        if ((size_t)ret_value >= size)
-            name[size - 1] = '\0';
+        strncpy(name, ltable.lnks[idx].name, MIN((*name_len + 1), name_size));
+        if (*name_len >= name_size)
+            name[name_size - 1] = '\0';
     } /* end if */
 
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_get_name_by_idx() */
@@ -254,32 +239,29 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  5 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5G__compact_remove_common_cb(const void *_mesg, unsigned H5_ATTR_UNUSED idx, void *_udata)
 {
     const H5O_link_t *lnk       = (const H5O_link_t *)_mesg; /* Pointer to link */
-    H5G_iter_rm_t *   udata     = (H5G_iter_rm_t *)_udata;   /* 'User data' passed in */
+    H5G_iter_rm_t    *udata     = (H5G_iter_rm_t *)_udata;   /* 'User data' passed in */
     herr_t            ret_value = H5_ITER_CONT;              /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk);
-    HDassert(udata);
+    assert(lnk);
+    assert(udata);
 
     /* If we've found the right link, get the object type */
-    if (HDstrcmp(lnk->name, udata->name) == 0) {
+    if (strcmp(lnk->name, udata->name) == 0) {
         /* Replace path names for link being removed */
         if (H5G__link_name_replace(udata->file, udata->grp_full_path_r, lnk) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5_ITER_ERROR, "unable to get object type")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5_ITER_ERROR, "unable to get object type");
 
         /* Stop the iteration, we found the correct link */
-        HGOTO_DONE(H5_ITER_STOP)
+        HGOTO_DONE(H5_ITER_STOP);
     } /* end if */
 
 done:
@@ -293,9 +275,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, September 19, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -306,8 +285,8 @@ H5G__compact_remove(const H5O_loc_t *oloc, H5RS_str_t *grp_full_path_r, const ch
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(oloc && oloc->file);
-    HDassert(name && *name);
+    assert(oloc && oloc->file);
+    assert(name && *name);
 
     /* Initialize data to pass through object header iteration */
     udata.file            = oloc->file;
@@ -315,8 +294,8 @@ H5G__compact_remove(const H5O_loc_t *oloc, H5RS_str_t *grp_full_path_r, const ch
     udata.name            = name;
 
     /* Iterate over the link messages to delete the right one */
-    if (H5O_msg_remove_op(oloc, H5O_LINK_ID, H5O_FIRST, H5G__compact_remove_common_cb, &udata, TRUE) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message")
+    if (H5O_msg_remove_op(oloc, H5O_LINK_ID, H5O_FIRST, H5G__compact_remove_common_cb, &udata, true) < 0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -329,9 +308,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, November 14, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -344,16 +320,16 @@ H5G__compact_remove_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5RS
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(oloc && oloc->file);
-    HDassert(linfo);
+    assert(oloc && oloc->file);
+    assert(linfo);
 
     /* Build table of all link messages, sorted according to desired order */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Check for going out of bounds */
     if (n >= ltable.nlinks)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound");
 
     /* Initialize data to pass through object header iteration */
     udata.file            = oloc->file;
@@ -361,13 +337,13 @@ H5G__compact_remove_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5RS
     udata.name            = ltable.lnks[n].name;
 
     /* Iterate over the link messages to delete the right one */
-    if (H5O_msg_remove_op(oloc, H5O_LINK_ID, H5O_FIRST, H5G__compact_remove_common_cb, &udata, TRUE) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message")
+    if (H5O_msg_remove_op(oloc, H5O_LINK_ID, H5O_FIRST, H5G__compact_remove_common_cb, &udata, true) < 0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message");
 
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_remove_by_idx() */
@@ -379,9 +355,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, October  3, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -395,13 +368,13 @@ H5G__compact_iterate(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_index_t
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(oloc);
-    HDassert(linfo);
-    HDassert(op);
+    assert(oloc);
+    assert(linfo);
+    assert(op);
 
     /* Build table of all link messages */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Iterate over links in table */
     if ((ret_value = H5G__link_iterate_table(&ltable, skip, last_lnk, op, op_data)) < 0)
@@ -410,7 +383,7 @@ H5G__compact_iterate(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_index_t
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_iterate() */
@@ -423,37 +396,34 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep 20 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5G__compact_lookup_cb(const void *_mesg, unsigned H5_ATTR_UNUSED idx, void *_udata)
 {
     const H5O_link_t *lnk       = (const H5O_link_t *)_mesg; /* Pointer to link */
-    H5G_iter_lkp_t *  udata     = (H5G_iter_lkp_t *)_udata;  /* 'User data' passed in */
+    H5G_iter_lkp_t   *udata     = (H5G_iter_lkp_t *)_udata;  /* 'User data' passed in */
     herr_t            ret_value = H5_ITER_CONT;              /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk);
-    HDassert(udata);
+    assert(lnk);
+    assert(udata);
 
     /* Check for name to get information */
-    if (HDstrcmp(lnk->name, udata->name) == 0) {
+    if (strcmp(lnk->name, udata->name) == 0) {
         if (udata->lnk) {
             /* Copy link information */
             if (NULL == H5O_msg_copy(H5O_LINK_ID, lnk, udata->lnk))
-                HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message");
         } /* end if */
 
         /* Indicate that the correct link was found */
-        udata->found = TRUE;
+        *udata->found = true;
 
         /* Stop iteration now */
-        HGOTO_DONE(H5_ITER_STOP)
+        HGOTO_DONE(H5_ITER_STOP);
     } /* end if */
 
 done:
@@ -465,39 +435,34 @@ done:
  *
  * Purpose:	Look up an object relative to a group, using link messages.
  *
- * Return:	Non-negative (TRUE/FALSE) on success/Negative on failure
- *
- * Programmer:	Quincey Koziol
- *		Sep 20 2005
+ * Return:	Non-negative (true/false) on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
-htri_t
-H5G__compact_lookup(const H5O_loc_t *oloc, const char *name, H5O_link_t *lnk)
+herr_t
+H5G__compact_lookup(const H5O_loc_t *oloc, const char *name, bool *found, H5O_link_t *lnk)
 {
-    H5G_iter_lkp_t      udata;            /* User data for iteration callback */
-    H5O_mesg_operator_t op;               /* Message operator */
-    htri_t              ret_value = FAIL; /* Return value */
+    H5G_iter_lkp_t      udata;               /* User data for iteration callback */
+    H5O_mesg_operator_t op;                  /* Message operator */
+    herr_t              ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk && oloc->file);
-    HDassert(name && *name);
+    assert(name && *name);
+    assert(found);
+    assert(lnk && oloc->file);
 
     /* Set up user data for iteration */
     udata.name  = name;
     udata.lnk   = lnk;
-    udata.found = FALSE;
+    udata.found = found;
 
     /* Iterate through the link messages, adding them to the table */
     op.op_type  = H5O_MESG_OP_APP;
     op.u.app_op = H5G__compact_lookup_cb;
     if (H5O_msg_iterate(oloc, H5O_LINK_ID, &op, &udata) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages")
-
-    /* Determine if we found the link we were looking for */
-    ret_value = (htri_t)udata.found;
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -511,9 +476,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Nov  6 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -526,26 +488,26 @@ H5G__compact_lookup_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_i
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(oloc && oloc->file);
-    HDassert(linfo);
-    HDassert(lnk);
+    assert(oloc && oloc->file);
+    assert(linfo);
+    assert(lnk);
 
     /* Build table of all link messages, sorted according to desired order */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Check for going out of bounds */
     if (n >= ltable.nlinks)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound");
 
     /* Copy link information */
     if (NULL == H5O_msg_copy(H5O_LINK_ID, &ltable.lnks[n], lnk))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message");
 
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_lookup_by_idx() */
