@@ -10,9 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *              Monday, December 4, 2006
- *
+/*
  * Purpose:	Object header testing functions.
  */
 
@@ -32,7 +30,6 @@
 #include "H5ACprivate.h" /* Metadata cache			*/
 #include "H5CXprivate.h" /* API Contexts                         */
 #include "H5Eprivate.h"  /* Error handling		  	*/
-#include "H5Iprivate.h"  /* IDs			  		*/
 #include "H5Opkg.h"      /* Object headers			*/
 
 /****************/
@@ -72,7 +69,7 @@
     htri_t H5O__is_attr_dense_test(oid)
         hid_t oid;              IN: object to check
  RETURNS
-    Non-negative TRUE/FALSE on success, negative on failure
+    Non-negative true/false on success, negative on failure
  DESCRIPTION
     Checks to see if the object is storing attributes in the "dense" or
     "compact" form.
@@ -88,47 +85,47 @@ H5O__is_attr_dense_test(hid_t oid)
     H5O_t      *oh = NULL;              /* Object header */
     H5O_ainfo_t ainfo;                  /* Attribute information for object */
     H5O_loc_t  *loc;                    /* Pointer to object's location */
-    hbool_t     api_ctx_pushed = FALSE; /* Whether API context pushed */
+    bool        api_ctx_pushed = false; /* Whether API context pushed */
     htri_t      ret_value      = FAIL;  /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Check for attribute info stored */
     ainfo.fheap_addr = HADDR_UNDEF;
     if (oh->version > H5O_VERSION_1) {
         /* Check for (& retrieve if available) attribute info */
         if (H5A__get_ainfo(loc->file, oh, &ainfo) < 0)
-            HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message")
+            HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message");
     } /* end if */
 
     /* Check if dense storage is being used */
-    if (H5F_addr_defined(ainfo.fheap_addr)) {
+    if (H5_addr_defined(ainfo.fheap_addr)) {
         /* Check for any messages in object header */
-        HDassert(H5O__msg_count_real(oh, H5O_MSG_ATTR) == 0);
+        assert(H5O__msg_count_real(oh, H5O_MSG_ATTR) == 0);
 
-        ret_value = TRUE;
+        ret_value = true;
     } /* end if */
     else
-        ret_value = FALSE;
+        ret_value = false;
 
 done:
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__is_attr_dense_test() */
@@ -142,7 +139,7 @@ done:
     htri_t H5O__is_attr_empty_test(oid)
         hid_t oid;              IN: object to check
  RETURNS
-    Non-negative TRUE/FALSE on success, negative on failure
+    Non-negative true/false on success, negative on failure
  DESCRIPTION
     Checks to see if the object is storing any attributes.
  GLOBAL VARIABLES
@@ -157,32 +154,32 @@ H5O__is_attr_empty_test(hid_t oid)
     H5O_t      *oh       = NULL;        /* Object header */
     H5B2_t     *bt2_name = NULL;        /* v2 B-tree handle for name index */
     H5O_ainfo_t ainfo;                  /* Attribute information for object */
-    htri_t      ainfo_exists = FALSE;   /* Whether the attribute info exists in the file */
+    htri_t      ainfo_exists = false;   /* Whether the attribute info exists in the file */
     H5O_loc_t  *loc;                    /* Pointer to object's location */
     hsize_t     nattrs;                 /* Number of attributes */
-    hbool_t     api_ctx_pushed = FALSE; /* Whether API context pushed */
+    bool        api_ctx_pushed = false; /* Whether API context pushed */
     htri_t      ret_value      = FAIL;  /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Check for attribute info stored */
     if (oh->version > H5O_VERSION_1) {
         /* Check for (& retrieve if available) attribute info */
         if ((ainfo_exists = H5A__get_ainfo(loc->file, oh, &ainfo)) < 0)
-            HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message")
+            HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message");
     } /* end if */
 
     /* Retrieve the number of attribute messages in header */
@@ -192,17 +189,17 @@ H5O__is_attr_empty_test(hid_t oid)
     if (oh->version > H5O_VERSION_1) {
         if (ainfo_exists) {
             /* Check for using dense storage */
-            if (H5F_addr_defined(ainfo.fheap_addr)) {
+            if (H5_addr_defined(ainfo.fheap_addr)) {
                 /* Check for any messages in object header */
-                HDassert(nattrs == 0);
+                assert(nattrs == 0);
 
                 /* Set metadata tag in API context */
-                H5_BEGIN_TAG(loc->addr);
+                H5_BEGIN_TAG(loc->addr)
 
                 /* Open the name index v2 B-tree */
                 if (NULL == (bt2_name = H5B2_open(loc->file, ainfo.name_bt2_addr, NULL)))
                     HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTOPENOBJ, FAIL,
-                                    "unable to open v2 B-tree for name index")
+                                    "unable to open v2 B-tree for name index");
 
                 /* Reset metadata tag in API context */
                 H5_END_TAG
@@ -210,27 +207,27 @@ H5O__is_attr_empty_test(hid_t oid)
                 /* Retrieve # of records in name index */
                 if (H5B2_get_nrec(bt2_name, &nattrs) < 0)
                     HGOTO_ERROR(H5E_OHDR, H5E_CANTCOUNT, FAIL,
-                                "unable to retrieve # of records from name index")
+                                "unable to retrieve # of records from name index");
             } /* end if */
 
             /* Verify that attribute count in object header is correct */
-            HDassert(nattrs == ainfo.nattrs);
+            assert(nattrs == ainfo.nattrs);
         } /* end if */
         else
-            HDassert(nattrs == 0);
+            assert(nattrs == 0);
     } /* end if */
 
     /* Set the return value */
-    ret_value = (nattrs == 0) ? TRUE : FALSE;
+    ret_value = (nattrs == 0) ? true : false;
 
 done:
     /* Release resources */
     if (bt2_name && H5B2_close(bt2_name) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index");
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__is_attr_empty_test() */
@@ -262,30 +259,30 @@ H5O__num_attrs_test(hid_t oid, hsize_t *nattrs)
     H5O_ainfo_t ainfo;                    /* Attribute information for object */
     H5O_loc_t  *loc;                      /* Pointer to object's location */
     hsize_t     obj_nattrs;               /* Number of attributes */
-    hbool_t     api_ctx_pushed = FALSE;   /* Whether API context pushed */
+    bool        api_ctx_pushed = false;   /* Whether API context pushed */
     herr_t      ret_value      = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Check for attribute info stored */
     ainfo.fheap_addr = HADDR_UNDEF;
     if (oh->version > H5O_VERSION_1) {
         /* Check for (& retrieve if available) attribute info */
         if (H5A__get_ainfo(loc->file, oh, &ainfo) < 0)
-            HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message")
+            HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message");
     } /* end if */
 
     /* Retrieve the number of attribute messages in header */
@@ -294,27 +291,27 @@ H5O__num_attrs_test(hid_t oid, hsize_t *nattrs)
     /* Check for later version of object header format */
     if (oh->version > H5O_VERSION_1) {
         /* Check for using dense storage */
-        if (H5F_addr_defined(ainfo.fheap_addr)) {
+        if (H5_addr_defined(ainfo.fheap_addr)) {
             /* Check for any messages in object header */
-            HDassert(obj_nattrs == 0);
+            assert(obj_nattrs == 0);
 
             /* Set metadata tag in API context */
-            H5_BEGIN_TAG(loc->addr);
+            H5_BEGIN_TAG(loc->addr)
 
             /* Open the name index v2 B-tree */
             if (NULL == (bt2_name = H5B2_open(loc->file, ainfo.name_bt2_addr, NULL)))
-                HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open v2 B-tree for name index")
+                HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open v2 B-tree for name index");
 
             /* Reset metadata tag in API context */
             H5_END_TAG
 
             /* Retrieve # of records in name index */
             if (H5B2_get_nrec(bt2_name, &obj_nattrs) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOUNT, FAIL, "unable to retrieve # of records from name index")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOUNT, FAIL, "unable to retrieve # of records from name index");
         } /* end if */
 
         /* Verify that attribute count in object header is correct */
-        HDassert(obj_nattrs == ainfo.nattrs);
+        assert(obj_nattrs == ainfo.nattrs);
     } /* end if */
 
     /* Set the number of attributes */
@@ -323,11 +320,11 @@ H5O__num_attrs_test(hid_t oid, hsize_t *nattrs)
 done:
     /* Release resources */
     if (bt2_name && H5B2_close(bt2_name) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index");
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__num_attrs_test() */
@@ -361,60 +358,60 @@ H5O__attr_dense_info_test(hid_t oid, hsize_t *name_count, hsize_t *corder_count)
     H5B2_t     *bt2_corder = NULL;        /* v2 B-tree handle for creation order index */
     H5O_ainfo_t ainfo;                    /* Attribute information for object */
     H5O_loc_t  *loc;                      /* Pointer to object's location */
-    hbool_t     api_ctx_pushed = FALSE;   /* Whether API context pushed */
+    bool        api_ctx_pushed = false;   /* Whether API context pushed */
     herr_t      ret_value      = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Set metadata tag in API context */
-    H5_BEGIN_TAG(loc->addr);
+    H5_BEGIN_TAG(loc->addr)
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Check for attribute info stored */
     ainfo.fheap_addr = HADDR_UNDEF;
     if (oh->version > H5O_VERSION_1) {
         /* Check for (& retrieve if available) attribute info */
         if (H5A__get_ainfo(loc->file, oh, &ainfo) < 0)
-            HGOTO_ERROR_TAG(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message")
+            HGOTO_ERROR_TAG(H5E_ATTR, H5E_CANTGET, FAIL, "can't check for attribute info message");
     } /* end if */
 
     /* Check for 'dense' attribute storage file addresses being defined */
-    if (!H5F_addr_defined(ainfo.fheap_addr))
-        HGOTO_DONE_TAG(FAIL)
-    if (!H5F_addr_defined(ainfo.name_bt2_addr))
-        HGOTO_DONE_TAG(FAIL)
+    if (!H5_addr_defined(ainfo.fheap_addr))
+        HGOTO_DONE_TAG(FAIL);
+    if (!H5_addr_defined(ainfo.name_bt2_addr))
+        HGOTO_DONE_TAG(FAIL);
 
     /* Open the name index v2 B-tree */
     if (NULL == (bt2_name = H5B2_open(loc->file, ainfo.name_bt2_addr, NULL)))
-        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open v2 B-tree for name index")
+        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open v2 B-tree for name index");
 
     /* Retrieve # of records in name index */
     if (H5B2_get_nrec(bt2_name, name_count) < 0)
-        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTCOUNT, FAIL, "unable to retrieve # of records from name index")
+        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTCOUNT, FAIL, "unable to retrieve # of records from name index");
 
     /* Check if there is a creation order index */
-    if (H5F_addr_defined(ainfo.corder_bt2_addr)) {
+    if (H5_addr_defined(ainfo.corder_bt2_addr)) {
         /* Open the creation order index v2 B-tree */
         if (NULL == (bt2_corder = H5B2_open(loc->file, ainfo.corder_bt2_addr, NULL)))
             HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for creation order index")
+                            "unable to open v2 B-tree for creation order index");
 
         /* Retrieve # of records in creation order index */
         if (H5B2_get_nrec(bt2_corder, corder_count) < 0)
             HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTCOUNT, FAIL,
-                            "unable to retrieve # of records from creation order index")
+                            "unable to retrieve # of records from creation order index");
     } /* end if */
     else
         *corder_count = 0;
@@ -425,13 +422,13 @@ H5O__attr_dense_info_test(hid_t oid, hsize_t *name_count, hsize_t *corder_count)
 done:
     /* Release resources */
     if (bt2_name && H5B2_close(bt2_name) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index");
     if (bt2_corder && H5B2_close(bt2_corder) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for creation order index")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for creation order index");
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__attr_dense_info_test() */
@@ -445,7 +442,7 @@ done:
  USAGE
     herr_t H5O__check_msg_marked_test(oid, flag_val)
         hid_t oid;              IN: Object to check
-        hbool_t flag_val;       IN: Desired flag value
+        bool flag_val;       IN: Desired flag value
  RETURNS
     Non-negative on success, negative on failure
  DESCRIPTION
@@ -458,7 +455,7 @@ done:
  REVISION LOG
 --------------------------------------------------------------------------*/
 herr_t
-H5O__check_msg_marked_test(hid_t oid, hbool_t flag_val)
+H5O__check_msg_marked_test(hid_t oid, bool flag_val)
 {
     H5O_t      *oh = NULL;           /* Object header */
     H5O_loc_t  *loc;                 /* Pointer to object's location */
@@ -470,11 +467,11 @@ H5O__check_msg_marked_test(hid_t oid, hbool_t flag_val)
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Locate "unknown" message  */
     for (idx = 0, idx_msg = &oh->mesg[0]; idx < oh->nmesgs; idx++, idx_msg++)
@@ -482,7 +479,7 @@ H5O__check_msg_marked_test(hid_t oid, hbool_t flag_val)
             /* Check for "unknown" message having the correct flags */
             if (((idx_msg->flags & H5O_MSG_FLAG_WAS_UNKNOWN) > 0) != flag_val)
                 HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL,
-                            "'unknown' message has incorrect 'was unknown' flag value")
+                            "'unknown' message has incorrect 'was unknown' flag value");
 
             /* Break out of loop, to indicate that the "unknown" message was found */
             break;
@@ -490,11 +487,11 @@ H5O__check_msg_marked_test(hid_t oid, hbool_t flag_val)
 
     /* Check for not finding an "unknown" message */
     if (idx == oh->nmesgs)
-        HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "'unknown' message type not found")
+        HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "'unknown' message type not found");
 
 done:
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__check_msg_marked_test() */
@@ -530,12 +527,12 @@ H5O__expunge_chunks_test(const H5O_loc_t *loc)
     FUNC_ENTER_PACKAGE
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__NO_FLAGS_SET, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__NO_FLAGS_SET, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header");
 
     /* Safety check */
     nchunks = oh->nchunks;
-    HDassert(0 < nchunks && nchunks < NELMTS(chk_addr));
+    assert(0 < nchunks && nchunks < NELMTS(chk_addr));
 
     /* Iterate over all the chunks, saving the chunk addresses */
     for (u = 0; u < oh->nchunks; u++)
@@ -543,14 +540,14 @@ H5O__expunge_chunks_test(const H5O_loc_t *loc)
 
     /* Release the object header */
     if (H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to unprotect object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to unprotect object header");
 
     /* Iterate over all the saved chunk addresses, evicting them from the cache */
     /* (in reverse order, so that chunk #0 is unpinned) */
     for (u = nchunks - 1; u < nchunks; u--)
         if (H5AC_expunge_entry(loc->file, (u == 0 ? H5AC_OHDR : H5AC_OHDR_CHK), chk_addr[u],
                                H5AC__NO_FLAGS_SET) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTEXPUNGE, FAIL, "unable to expunge object header chunk")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTEXPUNGE, FAIL, "unable to expunge object header chunk");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -585,12 +582,12 @@ H5O__get_rc_test(const H5O_loc_t *loc, unsigned *rc)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(loc);
-    HDassert(rc);
+    assert(loc);
+    assert(rc);
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object header");
 
     /* Save the refcount for the object header */
     *rc = oh->nlink;
@@ -598,7 +595,7 @@ H5O__get_rc_test(const H5O_loc_t *loc, unsigned *rc)
 done:
     /* Release the object header */
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to unprotect object header")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to unprotect object header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__get_rc_test() */
@@ -631,23 +628,23 @@ H5O__msg_get_chunkno_test(hid_t oid, unsigned msg_type, unsigned *chunk_num)
     H5O_loc_t  *loc;                      /* Pointer to object's location */
     H5O_mesg_t *idx_msg;                  /* Pointer to message */
     unsigned    idx;                      /* Index of message */
-    hbool_t     api_ctx_pushed = FALSE;   /* Whether API context pushed */
+    bool        api_ctx_pushed = false;   /* Whether API context pushed */
     herr_t      ret_value      = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Locate first message of given type */
     for (idx = 0, idx_msg = &oh->mesg[0]; idx < oh->nmesgs; idx++, idx_msg++)
@@ -661,13 +658,13 @@ H5O__msg_get_chunkno_test(hid_t oid, unsigned msg_type, unsigned *chunk_num)
 
     /* Check for not finding a message of the given type*/
     if (idx == oh->nmesgs)
-        HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "message of type not found")
+        HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "message of type not found");
 
 done:
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__msg_get_chunkno_test() */
@@ -698,23 +695,23 @@ H5O__msg_move_to_new_chunk_test(hid_t oid, unsigned msg_type)
     H5O_loc_t  *loc;                      /* Pointer to object's location */
     H5O_mesg_t *curr_msg;                 /* Pointer to current message */
     unsigned    idx;                      /* Index of message */
-    hbool_t     api_ctx_pushed = FALSE;   /* Whether API context pushed */
+    bool        api_ctx_pushed = false;   /* Whether API context pushed */
     herr_t      ret_value      = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Get object location for object */
     if (NULL == (loc = H5O_get_loc(oid)))
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "object not found");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Get the object header */
-    if (NULL == (oh = H5O_protect(loc, H5AC__NO_FLAGS_SET, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header")
+    if (NULL == (oh = H5O_protect(loc, H5AC__NO_FLAGS_SET, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to load object header");
 
     /* Locate first message of given type */
     for (idx = 0, curr_msg = &oh->mesg[0]; idx < oh->nmesgs; idx++, curr_msg++)
@@ -768,7 +765,7 @@ H5O__msg_move_to_new_chunk_test(hid_t oid, unsigned msg_type)
             /* (*new_idx returned from this routine is unused here) */
             if (H5O__alloc_chunk(loc->file, oh, (curr_msg->raw_size + (size_t)H5O_SIZEOF_MSGHDR_OH(oh)),
                                  oh->nmesgs, &found_msg, &new_idx) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTALLOC, FAIL, "can't allocate new object header chunk")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTALLOC, FAIL, "can't allocate new object header chunk");
 
             /* Break out of loop, the message was found */
             break;
@@ -776,9 +773,9 @@ H5O__msg_move_to_new_chunk_test(hid_t oid, unsigned msg_type)
 
 done:
     if (oh && H5O_unprotect(loc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__msg_move_to_new_chunk_test() */
