@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -14,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5checksum.c
- *			Aug 21 2006
- *			Quincey Koziol
  *
  * Purpose:		Internal code for computing fletcher32 checksums
  *
@@ -25,6 +22,7 @@
 /****************/
 /* Module Setup */
 /****************/
+#include "H5module.h" /* This source code file is part of the H5 module */
 
 /***********/
 /* Headers */
@@ -67,7 +65,7 @@
 static uint32_t H5_crc_table[256];
 
 /* Flag: has the table been computed? */
-static hbool_t H5_crc_table_computed = FALSE;
+static bool H5_crc_table_computed = false;
 
 /*-------------------------------------------------------------------------
  * Function:	H5_checksum_fletcher32
@@ -91,9 +89,6 @@ static hbool_t H5_crc_table_computed = FALSE;
  *
  * Return:	32-bit fletcher checksum of input buffer (can't fail)
  *
- * Programmer:	Quincey Koziol
- *              Monday, August 21, 2006
- *
  *-------------------------------------------------------------------------
  */
 uint32_t
@@ -106,11 +101,11 @@ H5_checksum_fletcher32(const void *_data, size_t _len)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
-    HDassert(_data);
-    HDassert(_len > 0);
+    assert(_data);
+    assert(_len > 0);
 
     /* Compute checksum for pairs of bytes */
-    /* (the magic "360" value is is the largest number of sums that can be
+    /* (the magic "360" value is the largest number of sums that can be
      *  performed without numeric overflow)
      */
     while (len) {
@@ -147,9 +142,6 @@ H5_checksum_fletcher32(const void *_data, size_t _len)
  *
  * Return:	none
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, September  5, 2006
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -158,7 +150,7 @@ H5__checksum_crc_make_table(void)
     uint32_t c;    /* Checksum for each byte value */
     unsigned n, k; /* Local index variables */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Compute the checksum for each possible byte value */
     for (n = 0; n < 256; n++) {
@@ -170,7 +162,7 @@ H5__checksum_crc_make_table(void)
                 c = c >> 1;
         H5_crc_table[n] = c;
     }
-    H5_crc_table_computed = TRUE;
+    H5_crc_table_computed = true;
 
     FUNC_LEAVE_NOAPI_VOID
 } /* end H5__checksum_crc_make_table() */
@@ -185,9 +177,6 @@ H5__checksum_crc_make_table(void)
  *
  * Return:	32-bit CRC checksum of input buffer (can't fail)
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, September  5, 2006
- *
  *-------------------------------------------------------------------------
  */
 static uint32_t
@@ -195,7 +184,7 @@ H5__checksum_crc_update(uint32_t crc, const uint8_t *buf, size_t len)
 {
     size_t n; /* Local index variable */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Initialize the CRC table if necessary */
     if (!H5_crc_table_computed)
@@ -220,9 +209,6 @@ H5__checksum_crc_update(uint32_t crc, const uint8_t *buf, size_t len)
  *
  * Return:	32-bit CRC checksum of input buffer (can't fail)
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, September  5, 2006
- *
  *-------------------------------------------------------------------------
  */
 uint32_t
@@ -231,8 +217,8 @@ H5_checksum_crc(const void *_data, size_t len)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
-    HDassert(_data);
-    HDassert(len > 0);
+    assert(_data);
+    assert(len > 0);
 
     FUNC_LEAVE_NOAPI(H5__checksum_crc_update((uint32_t)0xffffffffL, (const uint8_t *)_data, len) ^
                      0xffffffffL)
@@ -284,7 +270,7 @@ rotates.
 */
 #define H5_lookup3_rot(x, k) (((x) << (k)) ^ ((x) >> (32 - (k))))
 #define H5_lookup3_mix(a, b, c)                                                                              \
-    {                                                                                                        \
+    do {                                                                                                     \
         a -= c;                                                                                              \
         a ^= H5_lookup3_rot(c, 4);                                                                           \
         c += b;                                                                                              \
@@ -303,7 +289,7 @@ rotates.
         c -= b;                                                                                              \
         c ^= H5_lookup3_rot(b, 4);                                                                           \
         b += a;                                                                                              \
-    }
+    } while (0)
 
 /*
 -------------------------------------------------------------------------------
@@ -331,7 +317,7 @@ and these came close:
 -------------------------------------------------------------------------------
 */
 #define H5_lookup3_final(a, b, c)                                                                            \
-    {                                                                                                        \
+    do {                                                                                                     \
         c ^= b;                                                                                              \
         c -= H5_lookup3_rot(b, 14);                                                                          \
         a ^= c;                                                                                              \
@@ -346,7 +332,7 @@ and these came close:
         b -= H5_lookup3_rot(a, 14);                                                                          \
         c ^= b;                                                                                              \
         c -= H5_lookup3_rot(b, 24);                                                                          \
-    }
+    } while (0)
 
 /*
 -------------------------------------------------------------------------------
@@ -359,7 +345,7 @@ the return value.  Two keys differing by one or two bits will have
 totally different hash values.
 
 The best hash table sizes are powers of 2.  There is no need to do
-mod a prime (mod is sooo slow!).  If you need less than 32 bits,
+mod a prime (mod is so slow!).  If you need less than 32 bits,
 use a bitmask.  For example, if you need only 10 bits, do
   h = (h & hashmask(10));
 In which case, the hash table should have hashsize(10) elements.
@@ -379,13 +365,13 @@ uint32_t
 H5_checksum_lookup3(const void *key, size_t length, uint32_t initval)
 {
     const uint8_t *k = (const uint8_t *)key;
-    uint32_t       a, b, c; /* internal state */
+    uint32_t       a, b, c = 0; /* internal state */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
-    HDassert(key);
-    HDassert(length > 0);
+    assert(key);
+    assert(length > 0);
 
     /* Set up the internal state */
     a = b = c = 0xdeadbeef + ((uint32_t)length) + initval;
@@ -414,36 +400,47 @@ H5_checksum_lookup3(const void *key, size_t length, uint32_t initval)
     {
         case 12:
             c += ((uint32_t)k[11]) << 24;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 11:
             c += ((uint32_t)k[10]) << 16;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 10:
             c += ((uint32_t)k[9]) << 8;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 9:
             c += k[8];
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 8:
             b += ((uint32_t)k[7]) << 24;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 7:
             b += ((uint32_t)k[6]) << 16;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 6:
             b += ((uint32_t)k[5]) << 8;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 5:
             b += k[4];
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 4:
             a += ((uint32_t)k[3]) << 24;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 3:
             a += ((uint32_t)k[2]) << 16;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 2:
             a += ((uint32_t)k[1]) << 8;
+            /* FALLTHROUGH */
             H5_ATTR_FALLTHROUGH
         case 1:
             a += k[0];
@@ -451,7 +448,7 @@ H5_checksum_lookup3(const void *key, size_t length, uint32_t initval)
         case 0:
             goto done;
         default:
-            HDassert(0 && "This Should never be executed!");
+            assert(0 && "This Should never be executed!");
     }
 
     H5_lookup3_final(a, b, c);
@@ -469,9 +466,6 @@ done:
  *
  * Return:	checksum of input buffer (can't fail)
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, August 22, 2006
- *
  *-------------------------------------------------------------------------
  */
 uint32_t
@@ -480,8 +474,8 @@ H5_checksum_metadata(const void *data, size_t len, uint32_t initval)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
-    HDassert(data);
-    HDassert(len > 0);
+    assert(data);
+    assert(len > 0);
 
     /* Choose the appropriate checksum routine */
     /* (use Bob Jenkin's "lookup3" algorithm for all buffer sizes) */
@@ -498,9 +492,6 @@ H5_checksum_metadata(const void *data, size_t len, uint32_t initval)
  *
  * Return:	hash of input string (can't fail)
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, December 11, 2007
- *
  *-------------------------------------------------------------------------
  */
 uint32_t
@@ -512,7 +503,7 @@ H5_hash_string(const char *str)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
-    HDassert(str);
+    assert(str);
 
     while ((c = *str++))
         hash = ((hash << 5) + hash) + (uint32_t)c; /* hash * 33 + c */
